# float MNIST input
from variables import VariableGroup, VariableTensor, Bounded, OneHot

mnist_in = VariableGroup(name="mnist_in",
                         variables={
                             VariableTensor(Bounded(max=1, min=0), (28, 28))
                         })
mnist_out = VariableGroup(name="mnist_out",
                          variables={
                              VariableTensor(OneHot(n_category=10), (1,))
                          })



from setuptools import setup

setup(
    name='variable_protocols',
    version='1.1',
    packages=[''],
    package_data={'': ['py.typed']},
    url='https://github.com/cwhy/variable_protocols',
    license='GPL v3',
    author='cwhy',
    author_email='chenyu.nus@gmail.com',
    description='A protocol for machine learning variables'
)
